@@ -156,7 +156,7 @@ public class SocketAppenderTest {
         assertNotNull("No event retrieved", event);
         assertTrue("Incorrect event", event.getMessage().getFormattedMessage().equals("This is a test message"));
         assertTrue("Message not delivered via TCP", tcpTestServer.getCount() > 0);
-        assertEquals(expectedUuidStr, event.getContextMap().get(tcKey));
+        assertEquals(expectedUuidStr, event.getContextData().getValue(tcKey));
         event = tcpTestServer.getQueue().poll(3, TimeUnit.SECONDS);
         assertNotNull("No event retrieved", event);
         assertTrue("Incorrect event", event.getMessage().getFormattedMessage().equals("Throwing an exception"));
@@ -270,7 +270,7 @@ public class SocketAppenderTest {
     }
 
     public static class UdpSocketTestServer extends Thread {
-        
+
         private final DatagramSocket sock;
         private boolean shutdown = false;
         private Thread thread;
@@ -327,20 +327,25 @@ public class SocketAppenderTest {
 
     public static class TcpSocketTestServer extends Thread {
 
-        private final ServerSocket sock;
+        private final ServerSocket serverSocket;
         private volatile boolean shutdown = false;
         private volatile int count = 0;
         private final BlockingQueue<LogEvent> queue;
 
+        @SuppressWarnings("resource")
         public TcpSocketTestServer(final int port) throws IOException {
-            this.sock = new ServerSocket(port);
+            this(new ServerSocket(port));
+        }
+
+        public TcpSocketTestServer(final ServerSocket serverSocket) {
+            this.serverSocket = serverSocket;
             this.queue = new ArrayBlockingQueue<>(10);
         }
 
         public int getLocalPort() {
-            return sock.getLocalPort();
+            return serverSocket.getLocalPort();
         }
-        
+
         public void reset() {
             queue.clear();
             count = 0;
@@ -354,7 +359,7 @@ public class SocketAppenderTest {
         @Override
         public void run() {
             try {
-                try (final Socket socket = sock.accept()) {
+                try (final Socket socket = serverSocket.accept()) {
                     if (socket != null) {
                         final ObjectInputStream ois = new ObjectInputStream(socket.getInputStream());
                         while (!shutdown) {
